@@ -63,7 +63,7 @@ def main():
     ax1.legend(handler1+handler2,label1+label2,borderaxespad=0)
     ax1.grid(True)
     ax1.set_xticklabels(dd.index, rotation=45, ha='right')
-    plt.savefig("img.png")
+    plt.savefig("../results/results.png")
     plt.show()
 
 if __name__ == "__main__":
